%define	upstream_name	 libintl-perl
%define	upstream_version 1.35

%{?perl_default_filter}

Name:       perl-%{upstream_name}
Version:    %perl_convert_version %{upstream_version}
Release:    %mkrel 1

Summary:    A localization library for Perl
License:    LGPL
Group:      Development/Perl
Url:        https://metacpan.org/release/%{upstream_name}
Source0:    https://cpan.metacpan.org/authors/id/G/GU/GUIDO/%{upstream_name}-%{upstream_version}.tar.gz

BuildRequires: perl(ExtUtils::MakeMaker)
BuildRequires: perl(File::Spec)
BuildRequires: perl(version) >= 0.770.0
BuildRequires: gdbm-devel
BuildRequires: gettext-devel
BuildRequires: perl-devel
#gw yes, this is required by the tests
BuildRequires: locales-de
# Needed for tests/04find_domain_bug.t (fedora)
BuildRequires: locales-en
%description
libintl-perl is a library that supports message translation for
Perl, written in pure Perl (version 5.004 or better). A faster C
version is also built and installed if the system fulfills all
requirements. Its interface is very similar to the gettext family
of functions in C, and it uses the same file formats as GNU
gettext, making it possible to use all tools available for gettext
itself and to seamlessly integrate internationalized Perl code
into mixed-language projects. An alternative library with a
similar purpose is available as Locale::MakeText. 

%prep
%setup -q -n %{upstream_name}-%{upstream_version}
%autopatch -p1

%build
# fix build with modules from ./lib/:
export PERL_USE_UNSAFE_INC=1
%__perl Makefile.PL INSTALLDIRS=vendor
%make_build

%check
# 04find_domain_bug.t fails with Perl 5.28, if LANG is non-en_US
LANG=en_US %{__make} test

%install
# fix build with modules from ./lib/:
export PERL_USE_UNSAFE_INC=1
%make_install
# fix attribs
find %{buildroot}%{perl_vendorlib} -name "*.pm" | xargs chmod 755

%files
%doc COPYING Changes FAQ META.json META.yml MYMETA.yml NEWS README REFERENCES THANKS TODO sample
%{perl_vendorlib}/Locale
%{perl_vendorarch}/auto/Locale
%{_mandir}/*/*

%changelog
* Sat Jan 25 2025 tv <tv> 1.350.0-1.mga10
+ Revision: 2142194
- update to 1.35

* Thu Aug 22 2024 neoclust <neoclust> 1.330.0-3.mga10
+ Revision: 2088084
- Rebuild against new perl

* Tue Nov 28 2023 tv <tv> 1.330.0-2.mga10
+ Revision: 2010589
- Rebuild for perl-5.38

* Thu Dec 15 2022 tv <tv> 1.330.0-1.mga9
+ Revision: 1923073
- update to 1.33

* Tue Jun 07 2022 umeabot <umeabot> 1.320.0-4.mga9
+ Revision: 1862056
- Rebuild for Perl 5.36

* Fri Mar 18 2022 umeabot <umeabot> 1.320.0-3.mga9
+ Revision: 1797860
- Mageia 9 Mass Rebuild

* Mon May 24 2021 umeabot <umeabot> 1.320.0-2.mga9
+ Revision: 1726759
- Rebuild for perl 5.34

* Wed Oct 28 2020 tv <tv> 1.320.0-1.mga8
+ Revision: 1640046
- update to 1.32

* Wed Jun 17 2020 umeabot <umeabot> 1.310.0-4.mga8
+ Revision: 1594834
- Rebuild for perl 5.32

* Sat Feb 15 2020 umeabot <umeabot> 1.310.0-3.mga8
+ Revision: 1528739
- Mageia 8 Mass Rebuild

* Mon Aug 26 2019 tmb <tmb> 1.310.0-2.mga8
+ Revision: 1432578
- rebuild for perl 5.30

* Tue Nov 20 2018 tv <tv> 1.310.0-1.mga7
+ Revision: 1332385
- update to 1.31

* Mon Nov 05 2018 tv <tv> 1.300.0-1.mga7
+ Revision: 1328403
- update to 1.30

* Fri Sep 21 2018 umeabot <umeabot> 1.290.0-5.mga7
+ Revision: 1294083
- Mageia 7 Mass Rebuild

* Sun Aug 05 2018 tmb <tmb> 1.290.0-4.mga7
+ Revision: 1247768
- Run the tests with LANG=en_US to ensure we use the right dictionary (fedora)
- rebuild for perl 5.28

* Fri Mar 23 2018 wally <wally> 1.290.0-2.mga7
+ Revision: 1211599
- drop unneeded db4 BR

* Sun Dec 10 2017 shlomif <shlomif> 1.290.0-1.mga7
+ Revision: 1182048
- update to 1.29

* Tue Oct 03 2017 tv <tv> 1.280.0-2.mga7
+ Revision: 1165149
- rebuild with fixed rpm for missing autodeps

* Wed Sep 27 2017 tv <tv> 1.280.0-1.mga7
+ Revision: 1160168
- new release

* Thu Aug 31 2017 pterjan <pterjan> 1.240.0-8.mga7
+ Revision: 1149836
- Rebuild for perl ABI changes

* Sun Jul 23 2017 tv <tv> 1.240.0-7.mga7
+ Revision: 1129134
- use std macros
- fix build with perl 5.26
- fix build with perl 5.26
- rebuild for perl 5.26
+ neoclust <neoclust>
- Rebuild against new Perl 5.26

* Thu Apr 27 2017 neoclust <neoclust> 1.240.0-4.mga6
+ Revision: 1097803
- Add P0 - Fixes CVE-2016-1238 (mga#19051)

* Sun Jun 19 2016 pterjan <pterjan> 1.240.0-3.mga6
+ Revision: 1029138
- Rebuild for perl 5.22.2

* Fri Feb 12 2016 umeabot <umeabot> 1.240.0-2.mga6
+ Revision: 957617
- Mageia 6 Mass Rebuild

* Wed Jun 24 2015 guillomovitch <guillomovitch> 1.240.0-1.mga6
+ Revision: 842237
- new version 1.24

* Sat Oct 18 2014 umeabot <umeabot> 1.230.0-6.mga5
+ Revision: 788412
- Rebuild to potentially add missing dependencies

* Wed Oct 15 2014 umeabot <umeabot> 1.230.0-5.mga5
+ Revision: 743988
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 1.230.0-4.mga5
+ Revision: 687037
- Mageia 5 Mass Rebuild

* Wed Jun 04 2014 guillomovitch <guillomovitch> 1.230.0-3.mga5
+ Revision: 632842
- rebuild for new perl

* Sat Oct 19 2013 umeabot <umeabot> 1.230.0-2.mga4
+ Revision: 526301
- Mageia 4 Mass Rebuild

* Mon Jun 03 2013 jquelin <jquelin> 1.230.0-1.mga4
+ Revision: 436481
- update to 1.23

* Wed May 29 2013 tv <tv> 1.200.0-4.mga4
+ Revision: 430113
- rebuild for new perl

* Sun Jan 13 2013 umeabot <umeabot> 1.200.0-3.mga3
+ Revision: 375481
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sat Jun 11 2011 spuhler <spuhler> 1.200.0-2.mga2
+ Revision: 103993
- increase rel for rebuild

* Sat Jan 22 2011 jquelin <jquelin> 1.200.0-1.mga1
+ Revision: 31548
- mageia rebuild
- imported package perl-libintl-perl

